"""YAML tool, a clone of the json.tool Python module for YAML.

This tool provides a simple command line interface to validate and pretty-print
YAML documents while trying to preserve as much as possible from the original
documents (like comments and anchors).
"""


__version__ = "0.1.0"
